==> nextcloud-app-spreed-1%3A10.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ka_GE.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "Talk" : "საუბარი",
    "Guest" : "სტუმარი",
    "Talk to %s" : "საუბარი მომხმარებელთან %s",
    "Join call" : "შეუერთდით ზარს",
    "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "Open settings" : "პარამეტრების გახსნა",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Leave call" : "ზარის დატოვება",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Everyone" : "ყველა",
    "Save changes" : "ცვილებების შენახვა",
    "Saved!" : "შენახულია!",
    "None" : "არც ერთი",
    "User" : "მომხმარებელი",
    "Disabled" : "არაა მოქმედი",
    "Users" : "მომხმარებლები",
    "Name" : "სახელი",
    "General settings" : "მთავარი პარამეტრები",
    "Language" : "ენა",
    "Country" : "ქვეყანა",
    "Status" : "სტატუსი",
    "Created at" : "შეიქმნა",
    "Pending" : "მოლოდინში",
    "Error" : "შეცდომა",
    "Blocked" : "დაბლოკილია",
    "Expired" : "გაუქმდა",
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "Saved" : "დამახსოვრდა",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "UDP and TCP" : "UDP და TCP",
    "UDP only" : "მხოლოდ UDP",
    "TCP only" : "მხოლოდ TCP",
    "Copy link" : "ბმულის კოპირება",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "Dismiss" : "დათხოვნა",
    "Mute audio" : "ხმის ჩახშობა",
    "Disable video" : "ვიდეოს გათიშვა",
    "Enable video" : "ვიდეოს ამოქმედება",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "Back" : "უკან",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "You" : "თქვენ",
    "Show screen" : "ეკრანის ჩვენება",
    "Favorite" : "რჩეული",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Loading" : "იტვირთება",
    "Groups" : "ჯგუფები",
    "Circles" : "წრეები",
    "Settings" : "პარამეტრები",
    "Password protect" : "პაროლით დაცვა",
    "Close" : "დახურვა",
    "Conversation name" : "საუბრის სახელწოდება",
    "Reply" : "პასუხი",
    "Remove" : "წაშლა",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Enabled" : "მოქმედია",
    "Save" : "შენახვა",
    "Password" : "პაროლი",
    "API token" : "API ტოკენი",
    "Login" : "ავტორიზაცია",
    "Nickname" : "ნიკნეიმი",
    "Client ID" : "კლიენტის ID",
    "moderator" : "მოდერატორი",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Remove participant" : "მონაწილის ამოშლა",
    "No results" : "შედეგები არაა",
    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Edit" : "შეცვლა",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Search" : "ძიება",
    "Share link" : "ბმულის გაზიარება",
    "Password protection" : "პაროლით თავდაცვა",
    "Enter a password" : "შეიყვანეთ პაროლი",
    "Grid view" : "ბადისებური ხედი",
    "Default" : "საწყისი",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "TURN server" : "TURN სერვერი",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "Copy" : "კოპირება",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არ არის მხარდაჭერილი!",
    "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
    "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
    "Password required" : "საჭიროა პაროლი",
    "Cancel" : "უარყოფა",
    "Submit" : "გაგზავნა",
    "Guests" : "სტუმრები",
    "Change password" : "პაროლის შეცვლა",
    "Set password" : "პაროლის დაყენება",
    "Rename" : "სახელის შეცვლა",
    "Link copied!" : "ბმული დაკოპირდა!",
    "Conversation with {name}" : "საუბარი მომხმარებელთან {name}",
    "Error occurred while setting password" : "პაროლის დაყენებისას წარმოიქმნა შეცდომა",
    "No messages yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
    "Send" : "გაგზავნა",
    "Share" : "გაზიარება",
    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
    "Error occurred while sending message" : "წერილის გაგზავნისას წარმოიშვა შეცდომა",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
    "Waiting for {participantName} to join the call …" : "ზარში შემოსვლისთვის ველოდებით მომხმარებელს {participantName} …",
    "WebRTC is not supported in your browser :-/" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს :-/",
    "Waiting for camera and microphone permissions" : "ველოდებით კამერის და მიკროფონის უფლებებს",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "ამ აპლიკაციის გამოყენბისთვის გთხოვთ მიანიჭოთ ბრაუზერს წვდომა კამერასა და მიკროფონზე.",
    "Share screen" : "ეკრანის გაზიარება",
    "No Camera" : "კამერა არაა",
    "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
    "Favorited" : "დამატებულია რჩეულებში",
    "Your screen" : "თქვენი ეკრანი",
    "{participantName}'s screen" : "{participantName} მომხმარებლის ეკრანი",
    "Guest's screen" : "სტუმრის ეკრანი",
    "Contacts" : "კონტაქტები"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-spreed-1%3A10.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ka_GE.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "Talk" : "საუბარი",
    "Guest" : "სტუმარი",
    "Talk to %s" : "საუბარი მომხმარებელთან %s",
    "Join call" : "შეუერთდით ზარს",
    "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "Open settings" : "პარამეტრების გახსნა",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Leave call" : "ზარის დატოვება",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Everyone" : "ყველა",
    "Save changes" : "ცვილებების შენახვა",
    "Saved!" : "შენახულია!",
    "None" : "არც ერთი",
    "User" : "მომხმარებელი",
    "Disabled" : "არაა მოქმედი",
    "Users" : "მომხმარებლები",
    "Name" : "სახელი",
    "General settings" : "მთავარი პარამეტრები",
    "Language" : "ენა",
    "Country" : "ქვეყანა",
    "Status" : "სტატუსი",
    "Created at" : "შეიქმნა",
    "Pending" : "მოლოდინში",
    "Error" : "შეცდომა",
    "Blocked" : "დაბლოკილია",
    "Expired" : "გაუქმდა",
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "Saved" : "დამახსოვრდა",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "UDP and TCP" : "UDP და TCP",
    "UDP only" : "მხოლოდ UDP",
    "TCP only" : "მხოლოდ TCP",
    "Copy link" : "ბმულის კოპირება",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "Dismiss" : "დათხოვნა",
    "Mute audio" : "ხმის ჩახშობა",
    "Disable video" : "ვიდეოს გათიშვა",
    "Enable video" : "ვიდეოს ამოქმედება",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "You" : "თქვენ",
    "Show screen" : "ეკრანის ჩვენება",
    "Favorite" : "რჩეული",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Loading" : "იტვირთება",
    "Groups" : "ჯგუფები",
    "Circles" : "წრეები",
    "Settings" : "პარამეტრები",
    "Password protect" : "პაროლით დაცვა",
    "Back" : "უკან",
    "Close" : "დახურვა",
    "Conversation name" : "საუბრის სახელწოდება",
    "Reply" : "პასუხი",
    "Remove" : "წაშლა",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Enabled" : "მოქმედია",
    "Save" : "შენახვა",
    "Password" : "პაროლი",
    "API token" : "API ტოკენი",
    "Login" : "ავტორიზაცია",
    "Nickname" : "ნიკნეიმი",
    "Client ID" : "კლიენტის ID",
    "moderator" : "მოდერატორი",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Remove participant" : "მონაწილის ამოშლა",
    "No results" : "შედეგები არაა",
    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Edit" : "შეცვლა",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Search" : "ძიება",
    "Share link" : "ბმულის გაზიარება",
    "Password protection" : "პაროლით თავდაცვა",
    "Enter a password" : "შეიყვანეთ პაროლი",
    "Grid view" : "ბადისებური ხედი",
    "Send" : "გაგზავნა",
    "Default" : "საწყისი",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "TURN server" : "TURN სერვერი",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
    "Your screen" : "თქვენი ეკრანი",
    "Contacts" : "კონტაქტები",
    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
    "Guests" : "სტუმრები",
    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
    "Password required" : "საჭიროა პაროლი",
    "Cancel" : "უარყოფა",
    "Submit" : "გაგზავნა"
},
"nplurals=2; plural=(n!=1);");
